//  OptionMenu.cpp version 1.5
//  yudit package - Unicode Editor for the X Window System (and Linux) 
//
//  Author: gsinai@iname.com (Gaspar Sinai)
//  GNU Copyright (C) 1997,1998,1999  Gaspar Sinai
// 
//  yudit version 1.5  Copyright(C) 30 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.4  Copyright(C) 25 November, 1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.3  Copyright(C)  5 April,    1999, Tokyo Japan  Gaspar Sinai
//  yudit version 1.2  Copyright(C) 10 December, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.1  Copyright(C) 23 August,   1998, Tokyo Japan  Gaspar Sinai
//  yudit version 1.0  Copyright(C) 17 May,      1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.99 Copyright(C)  4 April,    1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.97 Copyright(C)  4 February, 1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.95 Copyright(C) 10 January,  1998, Tokyo Japan  Gaspar Sinai
//  yudit version 0.94 Copyright(C) 17 December, 1997, Tokyo Japan  Gaspar Sinai
//  yudit version 0.9 Copyright (C)  8 December, 1997, Tokyo Japan  Gaspar Sinai
//  yutex version 0.8 Copyright (C)  5 November, 1997, Tokyo Japan  Gaspar Sinai
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//

#include <UCommon.h>
#include <OptionMenu.h>
#include <Xm/MenuShell.h>
#include <Xm/RowColumn.h>
#include <Xm/PushB.h>
#include <Xm/Label.h>

//
// This option menu does not use the label for 
// the option menu. It creates one instead.
//
OptionMenu::OptionMenu(Widget parentIn, const char* title)
{
	char	*hack;
	hack = new char[strlen(title) + 1];
	strcpy (hack, title);

	label = XtVaCreateManagedWidget (title,
		xmLabelWidgetClass, parentIn,
		XmNalignment, XmALIGNMENT_BEGINNING,
		XtVaTypedArg, XmNlabelString,
		XmRString, title, strlen (title) + 1,
		0);

	manager = XmCreatePulldownMenu(parentIn, hack, 0, 0);
	delete hack;

	menuItems = 0;
	menuSize = 0;
	menuArraySize = 0;


	menu = XtVaCreateManagedWidget (title,
		xmRowColumnWidgetClass, parentIn,
		XmNrowColumnType, XmMENU_OPTION,
		XtVaTypedArg, XmNlabelString,
		XmRString, "", strlen ("") +1,
		XmNorientation, XmHORIZONTAL,
		XmNsubMenuId, manager,
		0);


}

OptionMenu::~OptionMenu()
{
	int	i;
	for (i=0; i<menuSize; i++)
	{
		XtDestroyWidget (menuItems[i]);
	}
	XtDestroyWidget (menu);
	//XtDestroyWidget (label);
	XtDestroyWidget (manager);
}

//
// Name is already translated
void
OptionMenu::addItem(const char* name, const char* labeIn)
{
	Widget*		newArray;
	int		newSize;
	const char*	labelStr;
	// make sure we can store it
	labelStr = (labeIn==0) ? name : labeIn;
	if (menuSize>=menuArraySize)
	{
		newSize = (menuArraySize==0)? 1 : menuArraySize<<1;
		newArray = new Widget[newSize];
		CHECKNULL (newArray);
		if (menuSize!=0)
		{
			memcpy (newArray, menuItems, menuSize *sizeof (Widget));
			delete menuItems;
		}
		menuItems = newArray;
		menuArraySize = newSize;
	}

	menuItems[menuSize] = XtVaCreateManagedWidget (name,
		xmPushButtonWidgetClass, manager,
		XtVaTypedArg, XmNlabelString,
		XmRString, labelStr, strlen (labelStr) + 1,
		0);
	menuSize++;
}

void
OptionMenu::addList(const AStringList& list)
{
	int		i;
	const char*	item;

	for (i=0; i<list.getSize(); i++)
	{
		item = list.at(i);
		addItem (item);
	}
	return;
}

void
OptionMenu::select(const char* name)
{
	int	i;

	// only every second is menu
	for (i=0; i<menuSize; i++)
	{
		if (strcmp (name, XtName(menuItems[i])) == 0)
		{
			XtVaSetValues (menu, XmNmenuHistory, menuItems[i], 0);
			return;
		}
	}
	return;
}

const char*
OptionMenu::get()
{
	Widget		pushbutton;

	pushbutton = 0;
	string = 0;
	XtVaGetValues (menu, XmNmenuHistory, &pushbutton, 0);
	if (pushbutton==0)
	{
		return 0;
	}
	string = (const char*) XtName (pushbutton);
	return (const char*) string;
}
